@@ -134,6 +134,7 @@ class GattCharacteristic(object):
         self.unit = ''
         self.arrayLen = 1
         self.nextVal = 0
+        self.style = ''
     
     def uuidArray(self):
         val = self.uuid 
@@ -288,6 +289,9 @@ class GattCharacteristic(object):
         if(self.isMask):
             json_dict['type'] = 'mask'
 
+        if(self.style != ''):
+            json_dict['style'] = self.style
+
         return json_dict
 
 class GattService(object):
