@@ -5,7 +5,7 @@
  * 
  */
 
-/* user-block-includes-start -------------------------------------------------*/
+/*user-block-includes-start -------------------------------------------------*/
 #include "Utilities/Interfaces/GattServer/gatt_server.h"
 #include "svc/${obj.prefix}_svc.h"
 
@@ -31,19 +31,32 @@ void ${obj.prefix}_svc_post_init_handler(void)
  */
 ${"mrt_status_t {0}_{1}_handler(mrt_gatt_evt_t* event)".format(obj.prefix,char.name.lower())}
 {
-
-    //${t.cTypeDict[char.type]}* ptrVal = (${t.cTypeDict[char.type]}*) event->mData.data; /* Cast pointer to correct data type*/
+%if (char.type == 'string') or (char.arrayLen > 1):
+    //${t.cTypeDict[char.type]}* val = ((${t.cTypeDict[char.type]}*) event->mData.data); /* Cast to correct data type*/
+%else: 
+    //${t.cTypeDict[char.type]} val = *((${t.cTypeDict[char.type]}*) event->mData.data); /* Cast to correct data type*/
+%endif
 
 % if char.isEnum> 0:
-/*  switch(*ptrVal)
-    {
+    //switch(*ptrVal)
+    //{
     % for val in char.vals:
-        case ${t.padAfter(obj.prefix +"_"+char.name + "_"+val.name+":" , 45).upper()}  /* ${val.desc} */
-            break;
+    //    case ${t.padAfter(obj.prefix +"_"+char.name + "_"+val.name+":" , 45).upper()}  /* ${val.desc} */
+    //        //TODO Handle ${val.name}
+    //        break;
+    % endfor
+    //    default: 
+    //        break;
+    //}
+
+%endif
+% if char.isMask> 0:
+    % for val in char.vals:
+    //if(val & ${t.padAfter(obj.prefix +"_"+char.name + "_"+val.name+")" , 45).upper()}  /* ${val.desc} */
+    //{
+    //  //TODO Handle ${val.name} 
+    //}
     % endfor
-        default: 
-            break;
-    }/*
 
 %endif
     //TODO Handle ${char.name} Characteristic events
